@@ -2,7 +2,7 @@ from vkontakte_groups.factories import GroupFactory
 from models import GroupMigration
 import factory
 
-class GroupMigrationFactory(factory.Factory):
+class GroupMigrationFactory(factory.DjangoModelFactory):
     FACTORY_FOR = GroupMigration
 
     group = factory.SubFactory(GroupFactory)
\ No newline at end of file
